@@ -81,6 +81,7 @@ class Media(BaseModel):
     user: UserShort
     comment_count: int
     like_count: int
+    has_liked: Optional[bool]
     caption_text: str
     usertags: List[Usertag]
     video_url: Optional[HttpUrl]  # for Video and IGTV
@@ -122,6 +123,8 @@ class Comment(BaseModel):
     created_at_utc: datetime
     content_type: str
     status: str
+    has_liked: Optional[bool]
+    like_count: Optional[int]
 
 
 class StoryMention(BaseModel):
@@ -187,6 +190,19 @@ class DirectThread(BaseModel):
     shh_mode_enabled: bool
     last_seen_at: dict
 
+    def is_seen(self, user_id: int):
+        """Have I seen this thread?
+        :param user_id: You account user_id
+        """
+        user_id = str(user_id)
+        own_timestamp = int(self.last_seen_at[user_id]['timestamp'])
+        timestamps = [
+            (int(v['timestamp']) - own_timestamp) > 0
+            for k, v in self.last_seen_at.items()
+            if k != user_id
+        ]
+        return not any(timestamps)
+
 
 class Hashtag(BaseModel):
     id: int
